########
Tutorial
########

This tutorial will walk you through the installation as well as the most important features of BigJob. Many of these examples illustrate common workflow usages as well as distributed data movement.

**Prerequisites:**

* You are familiar with Linux or UNIX 
* You can read and write Python code
* You can use SSH and understand how public and private keys work
* You understand the basic concepts of distributed computing

**You will learn how to:**

* Install BigJob into user space on your own machine or XSEDE resource
* Learn to submit multiple jobs through a 'container job' to either your local machine or a remote resource
* Write a program that runs multiple jobs to form a simple ensemble workflow
* Write programs that demonstrate more complex, frequently used workflows 
* Use file transfer capabilities to transfer input files to the location of an executable

**Contents:**

.. toctree::
   :numbered:
   :maxdepth: 1

   part1
   part2
   part3
   part4
   table
